/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2020 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.archetype.test.builder.party;

import org.openvpms.archetype.rules.party.ContactArchetypes;
import org.openvpms.component.model.bean.IMObjectBean;
import org.openvpms.component.model.object.IMObject;
import org.openvpms.component.model.party.Contact;
import org.openvpms.component.service.archetype.ArchetypeService;

import java.util.Set;

/**
 * Builder for <em>contact.phoneNumber</em> instances, for testing purposes.
 *
 * @author Tim Anderson
 */
public class TestPhoneContactBuilder extends AbstractTestContactBuilder<TestPhoneContactBuilder> {

    /**
     * The area code.
     */
    private String areaCode;

    /**
     * The phone number.
     */
    private String phoneNumber;

    /**
     * Determines if the phone can be sent SMS messages.
     */
    private boolean sms;

    /**
     * Constructs a {@link TestPhoneContactBuilder}.
     *
     * @param service the archetype service
     */
    public TestPhoneContactBuilder(ArchetypeService service) {
        super(ContactArchetypes.PHONE, service);
    }

    /**
     * Sets the area code.
     *
     * @param areaCode the area code
     * @return this
     */
    public TestPhoneContactBuilder areaCode(String areaCode) {
        this.areaCode = areaCode;
        return this;
    }

    /**
     * Sets the phone number.
     *
     * @param phoneNumber the phone number
     * @return this
     */
    public TestPhoneContactBuilder phone(String phoneNumber) {
        this.phoneNumber = phoneNumber;
        return this;
    }

    /**
     * Marks the phone as accepting SMS messages.
     *
     * @return this
     */
    public TestPhoneContactBuilder sms() {
        return sms(true);
    }

    /**
     * Determines if the phone can accept SMS messages.
     *
     * @param sms if {@code true} the phone can accept SMS messages
     * @return this
     */
    public TestPhoneContactBuilder sms(boolean sms) {
        this.sms = sms;
        return this;
    }

    /**
     * Builds the object.
     *
     * @param object the object
     * @param bean   a bean wrapping the object
     * @param toSave objects to save, if the object is to be saved
     */
    @Override
    protected void build(Contact object, IMObjectBean bean, Set<IMObject> toSave) {
        super.build(object, bean, toSave);
        bean.setValue("areaCode", areaCode);
        bean.setValue("telephoneNumber", phoneNumber);
        bean.setValue("sms", sms);
    }
}
