/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2020 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.archetype.test.builder.scheduling;

import org.openvpms.archetype.rules.workflow.ScheduleArchetypes;
import org.openvpms.archetype.test.builder.entity.AbstractTestEntityBuilder;
import org.openvpms.archetype.test.builder.object.ValueStrategy;
import org.openvpms.component.model.bean.IMObjectBean;
import org.openvpms.component.model.entity.Entity;
import org.openvpms.component.model.object.IMObject;
import org.openvpms.component.service.archetype.ArchetypeService;

import java.util.Set;

/**
 * Builder for <em>entity.appointmentType</em> instances, for testing purposes.
 *
 * @author Tim Anderson
 */
public class TestAppointmentTypeBuilder extends AbstractTestEntityBuilder<Entity, TestScheduleBuilder> {

    /**
     * Determines if online booking is enabled.
     */
    private ValueStrategy onlineBooking = ValueStrategy.defaultValue();

    /**
     * Constructs an {@link TestAppointmentTypeBuilder}.
     *
     * @param service the archetype service
     */
    public TestAppointmentTypeBuilder(ArchetypeService service) {
        super(ScheduleArchetypes.APPOINTMENT_TYPE, Entity.class, service);
        name(ValueStrategy.random("zappointmenttype"));
    }

    /**
     * Make the appointment type available for online booking.
     *
     * @return this
     */
    public TestAppointmentTypeBuilder onlineBooking() {
        return onlineBooking(true);
    }

    /**
     * Determines if the appointment type is available for online booking.
     *
     * @param onlineBooking if {@code true}, the appointment type is available for online booking
     * @return this
     */
    public TestAppointmentTypeBuilder onlineBooking(boolean onlineBooking) {
        this.onlineBooking = ValueStrategy.value(onlineBooking);
        return this;
    }

    /**
     * Builds the object.
     *
     * @param object the object
     * @param bean   a bean wrapping the object
     * @param toSave objects to save, if the object is to be saved
     */
    @Override
    protected void build(Entity object, IMObjectBean bean, Set<IMObject> toSave) {
        super.build(object, bean, toSave);
        onlineBooking.setValue(bean, "onlineBooking");
    }
}
