/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2020 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.archetype.test.tools;

import org.openvpms.archetype.test.builder.customer.TestCustomerFactory;
import org.openvpms.archetype.test.builder.customer.account.TestCustomerAccountFactory;
import org.openvpms.archetype.test.builder.patient.TestPatientFactory;
import org.openvpms.archetype.test.builder.product.TestProductFactory;
import org.openvpms.component.model.party.Party;
import org.openvpms.component.model.product.Product;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;
import org.springframework.context.support.FileSystemXmlApplicationContext;

import java.io.File;

/**
 * Generates invoices.
 *
 * @author Tim Anderson
 */
public class TestInvoiceGenerator {

    /**
     * Main line.
     *
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        String contextPath = "applicationContext.xml";
        ApplicationContext context;
        if (!new File(contextPath).exists()) {
            context = new ClassPathXmlApplicationContext(contextPath);
        } else {
            context = new FileSystemXmlApplicationContext(contextPath);
        }
        TestCustomerFactory customerFactory = context.getBean(TestCustomerFactory.class);
        TestPatientFactory patientFactory = context.getBean(TestPatientFactory.class);
        TestCustomerAccountFactory accountFactory = context.getBean(TestCustomerAccountFactory.class);
        TestProductFactory productFactory = context.getBean(TestProductFactory.class);
        Product product1 = productFactory.createService();
        Product product2 = productFactory.createService();
        for (int i = 0; i < 100; ++i) {
            Party customer = customerFactory.createCustomer();
            Party patient = patientFactory.createPatient(customer);
            accountFactory.newInvoice()
                    .customer(customer)
                    .item().patient(patient).product(product1).quantity(1).fixedPrice(10)
                    .add()
                    .item().patient(patient).product(product2).quantity(2).unitPrice(3)
                    .add()
                    .build();
        }
    }
}