/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2020 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.sms.message;

import java.time.OffsetDateTime;

/**
 * A reply to an SMS {@link Message}.
 *
 * @author Tim Anderson
 */
public interface Reply {

    /**
     * Returns the OpenVPMS identifier for this reply.
     *
     * @return the identifier
     */
    long getId();

    /**
     * Returns the reply identifier, issued by the SMS provider.
     *
     * @return the reply identifier, or {@code null} if none has been issued
     */
    String getProviderId();

    /**
     * Returns the time when the reply was received.
     *
     * @return the reply receipt time
     */
    OffsetDateTime getReceived();

    /**
     * Returns the phone number.
     *
     * @return the phone number
     */
    String getPhone();

    /**
     * Returns the message text.
     *
     * @return the message text
     */
    String getMessage();

}
