/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2020 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.web.component.im.doc;

import org.openvpms.archetype.rules.doc.TextDocumentHandler;
import org.openvpms.component.business.domain.im.document.Document;
import org.openvpms.component.business.service.archetype.IArchetypeService;
import org.openvpms.component.model.bean.IMObjectBean;
import org.openvpms.component.model.object.IMObject;
import org.openvpms.web.component.property.Property;
import org.openvpms.web.component.property.PropertySet;
import org.openvpms.web.component.property.SimpleProperty;
import org.openvpms.web.system.ServiceHelper;

/**
 * Helper to for laying out text nodes that are backed by a document when their content grows too large.
 *
 * @author Tim Anderson
 * @see DocumentBackedTextNodeEditor
 */
public class DocumentBackedTextNodeLayout {

    /**
     * The text node name.
     */
    private final String textName;

    /**
     * The document node name.
     */
    private final String documentName;

    /**
     * Constructs a {@link DocumentBackedTextNodeEditor}.
     *
     * @param textName     the text node name
     * @param documentName the document node name
     */
    public DocumentBackedTextNodeLayout(String textName, String documentName) {
        this.textName = textName;
        this.documentName = documentName;
    }

    /**
     * Returns the text node, or a proxy for the node if the content is held in a document.
     *
     * @param object     the parent object
     * @param properties the properties
     * @return the text node
     */
    public Property getText(IMObject object, PropertySet properties) {
        IArchetypeService service = ServiceHelper.getArchetypeService();
        IMObjectBean bean = service.getBean(object);
        Property text = properties.get(textName);
        Document content = bean.getObject(documentName, Document.class);
        if (content != null) {
            TextDocumentHandler handler = new TextDocumentHandler(service);
            text = new SimpleProperty(textName, handler.toString(content), String.class, text.getDisplayName());
        }
        return text;
    }

}
