/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2019 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.web.workspace.admin.laboratory;

import org.openvpms.component.business.domain.im.common.Entity;
import org.openvpms.component.business.domain.im.common.IMObject;
import org.openvpms.laboratory.service.LaboratoryService;
import org.openvpms.laboratory.service.LaboratoryServices;
import org.openvpms.mapping.service.MappingProvider;
import org.openvpms.web.component.im.edit.IMObjectEditor;
import org.openvpms.web.component.im.layout.LayoutContext;
import org.openvpms.web.system.ServiceHelper;
import org.openvpms.web.workspace.admin.organisation.AbstractMappingPluginEditor;
import org.openvpms.web.workspace.admin.organisation.PluginEditor;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * An editor for <em>entity.laboratoryService*</em> plugin configurations.
 * <p/>
 * This supports plugins that implement the {@link MappingProvider} interface; a mapping tab will
 * be added when the laboratory service is configured.
 *
 * @author Tim Anderson
 */
public class LaboratoryServiceEditor extends AbstractMappingPluginEditor {

    /**
     * The logger.
     */
    private static final Logger log = LoggerFactory.getLogger(PluginEditor.class);

    /**
     * Constructs a {@link LaboratoryServiceEditor}.
     *
     * @param object        the object to edit
     * @param parent        the parent object. May be {@code null}
     * @param layoutContext the layout context
     */
    public LaboratoryServiceEditor(Entity object, IMObject parent, LayoutContext layoutContext) {
        super(object, parent, layoutContext);
    }

    /**
     * Creates a new instance of the editor, with the latest instance of the object to edit.
     *
     * @return a new instance of the editor
     */
    @Override
    public IMObjectEditor newInstance() {
        return new LaboratoryServiceEditor((Entity) reload(getObject()), getParent(), getLayoutContext());
    }

    /**
     * Determines if the plugin configuration is associated with a {@link MappingProvider}.
     *
     * @param config the plugin configuration
     * @return the mapping provider, or {@code null} if the service doesn't implement the {@link MappingProvider}
     * interface
     */
    @Override
    protected MappingProvider getMappingProvider(IMObject config) {
        MappingProvider result = null;
        try {
            LaboratoryService service = ServiceHelper.getBean(LaboratoryServices.class).getService((Entity) config);
            result = (service instanceof MappingProvider) ? (MappingProvider) service : null;
        } catch (Throwable exception) {
            log.warn(exception.getMessage(), exception);
        }
        return result;
    }
}
